
leaderproportionsUK<-function(leadpositions=NA,data=NA,speeches=NA) {
	
	leaderposition<-data
	
		if(1%in%leadpositions==TRUE){
		cat("Backbenchers cannot be excluded (category 1)!\n")
		stop()
	}

	pid<-leaderposition[,2]
	name<-leaderposition[,c(3:4)]
	status<-leaderposition[,c(5:ncol(leaderposition))]
	
	timeindex<-seq(from=1,to=ncol(status),by=1)
	
# create holding matrices for results, i.e. proportion of speeches for each party
	leader.res<-as.data.frame(matrix(NA,length(timeindex),6))
	names(leader.res)<-c("Leader speeches","Backbencher speeches","Prop. of leader MP speeches","Prop. of leader MP speeches CI lower","Prop. of leader MP speeches CI upper","Prop. of leader MPs in HC")
	rownames(leader.res)<-colnames(status)
	

# loop over number of actual months and do for each month
	for (k in timeindex) {	
		
# select backbenchers in this month
		backbenchers<-leaderposition[leaderposition[,k+4]==1,]
		backbenchers<-subset(backbenchers,select=c("mpid","PID","Surname","Name"))
		
		partyleaders<-leaderposition[leaderposition[,k+4]%in%leadpositions==TRUE,]
		partyleaders<-subset(partyleaders,select=c("mpid","PID","Surname","Name"))
		
				
# extract speech counts for these two groups 
		leader.speeches<-speeches[speeches$mpid%in%partyleaders$mpid==TRUE,k+3]
		backbencher.speeches<-speeches[speeches$mpid%in%backbenchers$mpid==TRUE,k+3]
		
# write number of speeches to output
		leader.res[k,1]<-sum(leader.speeches)
		leader.res[k,2]<-sum(backbencher.speeches)
		
# calculate proportion of leader speeches to backbencher speeches
		leader.res[k,3]<-sum(leader.speeches)/(sum(backbencher.speeches)+sum(leader.speeches))
		leader.res[k,6]<-nrow(partyleaders)/(nrow(backbenchers)+nrow(partyleaders))
		
# generate confidence intervals for proportion via nonparametric bootstrap
		boots<-rep(NA,1000)
		
		for (j in 1:1000) {
			
			boot.leaders<-sample(leader.speeches,length(leader.speeches),replace=TRUE)
			boot.backbenchers<-sample(backbencher.speeches,length(backbencher.speeches),replace=TRUE)
			boots[j]<-sum(boot.leaders) / (sum(boot.backbenchers)+sum (boot.leaders))
		}
		
# record lower and upper limit of confidence interval
		if (sum(is.na(boots))==0) 	leader.res[k,4]<-quantile(boots,0.025)
		if (sum(is.na(boots))==0) 	leader.res[k,5]<-quantile(boots,0.975)
		
		
		
	}
	
	return(leader.res)
}





plotleadertermUK<-function(data=NA,plotleg=TRUE,legendpos=c(25,0.95),mytitle=NA,xlabtitle=NA){


data<-data[rev(order(rownames(data))),]


par(mar=c(4,7,3,2))

plot(c(0,1),c(0.5,dim(data)[1]+0.5),type="n",xlim=c(0,1),xaxt="n",yaxt="n",main=mytitle,xlab="",ylab="")


rownames(data)[rownames(data)=="positionterm19972001"]<-"1997-2001"
rownames(data)[rownames(data)=="positiontermgov19972001"]<-"1997-2001"
rownames(data)[rownames(data)=="positionterm20012005"]<-"2001-2005"
rownames(data)[rownames(data)=="positiontermgov20012005"]<-"2001-2005"

axis(2,at=1:dim(data)[1],labels=rownames(data),cex.axis=1,las=1)
axis(1,at=seq(0,1,by=0.1),labels=TRUE,cex.axis=1)

mtext("Legislative Term",2,line=5.5,cex=1)
mtext(xlabtitle,1,line=2.5,cex=1)

segments(0,1:dim(data)[1],1,1:dim(data)[1],lty="dotted",col="gray25")#draw lines
segments(data[,4],1:dim(data)[1],data[,5],1:dim(data)[1],lwd=2)
segments(data[,4],1:dim(data)[1]-0.05,data[,4],1:dim(data)[1]+0.05,lwd=2)
segments(data[,5],1:dim(data)[1]-0.05,data[,5],1:dim(data)[1]+0.05,lwd=2)

segments(data[,6],1:dim(data)[1]-0.45,data[,6],1:dim(data)[1]+0.45,lty="dashed",col="red4",lwd=3)


for (k in 1:dim(data)[1]){
	if (data[k,4]>data[k,6]||data[k,5]<data[k,6]){
	points(data[k,3],k,pch=19,cex=1.5)}
	else{points(data[k,3],k,pch=21,cex=1.5,bg="gray")}
	
#	text(0.65,k+0.25,paste("Leader speeches: ",data[k,1]," (n=",data[k,7],")",sep=""),cex=0.6,adj=c(0,0))
#	text(0.65,k+0.1,paste("Backbencher speeches: ",data[k,2]," (n=",data[k,8],")",sep=""),cex=0.6,adj=c(0,0))
	#text(0.82,k+0.1,paste("MP coverage rate: ",round(data[k,9],2),sep=""),cex=0.6,adj=c(0,0))
	}



if(plotleg==TRUE){legend(legendpos[1],legendpos[2],c("Proportion of Party Leader MP speeches","Proportion of Party Leader MPs"),lty=c("solid","dotted"),lwd=c(1,2))}


}